@@ -68,6 +68,9 @@ bool tmp_dh_use;
 std::string tmp_dh_dir;
 std::string tmp_dh_file;
 std::string cipher_list;
+long session_cache_mode;
+long session_cache_size;
+long session_cache_timeout;
 std::string conn_log_flag;
 
 /*!
@@ -1076,6 +1079,87 @@ static int getParameters(std::string config_filename)
 			cipher_list = DEFAULT_CIPHER_LIST;
 		}
 
+		// Get parameter "session_cache".
+		if (Parameter::getInstance().isStringExist(PARAM_COMP_SSLPROXY, "session_cache")) {
+			std::string session_cache = Parameter::getInstance().getStringValue(PARAM_COMP_SSLPROXY, 
+										"session_cache");
+			/*-------- DEBUG LOG --------*/
+			if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_COMMON)) {
+				LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_COMMON, 97,
+					"function : static int getParameters("
+					"std::string config_filename) : "
+					"get session_cache OK.");
+			}
+			/*------ DEBUG LOG END ------*/
+			if (session_cache == "") {
+				LOGGER_PUT_LOG_WARN(LOG_CAT_SSLPROXY_COMMON, 25, 
+						    "session_cache parameter is nothing. "
+						    "Use default value.");
+				session_cache_mode = DEFAULT_SESSION_CACHE_MODE;
+			} else if (session_cache == "on") {
+				session_cache_mode = SSL_SESS_CACHE_SERVER;
+			} else if (session_cache == "off") {
+				session_cache_mode = SSL_SESS_CACHE_OFF;
+			} else {
+				LOGGER_PUT_LOG_ERROR(LOG_CAT_SSLPROXY_COMMON, 47, 
+						     "Invalid session_cache parameter value.");
+				throw -1;
+			}
+		} else {
+			LOGGER_PUT_LOG_WARN(LOG_CAT_SSLPROXY_COMMON, 26, 
+					    "session_cache parameter not found. "
+					    "Use default value.");
+			session_cache_mode = DEFAULT_SESSION_CACHE_MODE;
+		}
+
+		// Get parameter "session_cache_size".
+		if (Parameter::getInstance().isIntExist(PARAM_COMP_SSLPROXY, "session_cache_size")) {
+			session_cache_size = Parameter::getInstance().getIntValue(PARAM_COMP_SSLPROXY, 
+									  "session_cache_size");
+			/*-------- DEBUG LOG --------*/
+			if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_COMMON)) {
+				LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_COMMON, 98,
+					"function : static int getParameters("
+					"std::string config_filename) : "
+					"get session_cache_size OK.");
+			}
+			/*------ DEBUG LOG END ------*/
+			if (session_cache_size < 0 || session_cache_size > LONG_MAX) {
+				LOGGER_PUT_LOG_ERROR(LOG_CAT_SSLPROXY_COMMON, 48, 
+						     "Invalid session_cache_size parameter value.");
+				throw -1;
+			}
+		} else {
+			LOGGER_PUT_LOG_WARN(LOG_CAT_SSLPROXY_COMMON, 27, 
+					    "session_cache_size parameter not found. "
+					    "Use default value.");
+			session_cache_size = DEFAULT_SESSION_CACHE_SIZE;
+		}
+
+		// Get parameter "session_cache_timeout".
+		if (Parameter::getInstance().isIntExist(PARAM_COMP_SSLPROXY, "session_cache_timeout")) {
+			session_cache_timeout = Parameter::getInstance().getIntValue(PARAM_COMP_SSLPROXY, 
+									  "session_cache_timeout");
+			/*-------- DEBUG LOG --------*/
+			if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_COMMON)) {
+				LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_COMMON, 99,
+					"function : static int getParameters("
+					"std::string config_filename) : "
+					"get session_cache_timeout OK.");
+			}
+			/*------ DEBUG LOG END ------*/
+			if (session_cache_timeout < 0 || session_cache_timeout > LONG_MAX) {
+				LOGGER_PUT_LOG_ERROR(LOG_CAT_SSLPROXY_COMMON, 48, 
+						     "Invalid session_cache_timeout parameter value.");
+				throw -1;
+			}
+		} else {
+			LOGGER_PUT_LOG_WARN(LOG_CAT_SSLPROXY_COMMON, 28, 
+					    "session_cache_timeout parameter not found. "
+					    "Use default value.");
+			session_cache_timeout = DEFAULT_SESSION_CACHE_TIMEOUT;
+		}
+
 		// Get parameter "conn_log_flag".
 		if (Parameter::getInstance().isStringExist(PARAM_COMP_LOGGER, "conn_log_flag")) {
 			conn_log_flag = Parameter::getInstance().getStringValue(PARAM_COMP_LOGGER, 
@@ -1140,6 +1224,9 @@ static int getParameters(std::string config_filename)
 		", tmp_dh_dir = "		<< tmp_dh_dir			<<
 		", tmp_dh_file = "		<< tmp_dh_file			<<
 		", cipher_list = "		<< cipher_list			<<
+		", session_cache_mode = "	<< session_cache_mode		<<
+		", session_cache_size = "	<< session_cache_size		<<
+		", session_cache_timeout = "	<< session_cache_timeout	<<
 		", conn_log_flag = "		<< conn_log_flag;
 		LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_COMMON, 63,
 			"out_function : "
