@@ -285,7 +285,6 @@ sslproxy_server::sslproxy_server(boost::asio::io_service& io_service,
 			/*------ DEBUG LOG END ------*/
 		}
 
-
 		// Set cipher list on the context.
 		if (SSL_CTX_set_cipher_list(sslcontext.impl(), cipher_list.c_str()) != 1) {
 			std::cerr << "Set cipher list error : no valid ciphers." << std::endl;
@@ -303,6 +302,42 @@ sslproxy_server::sslproxy_server(boost::asio::io_service& io_service,
 		}
 		/*------ DEBUG LOG END ------*/
 
+		// Set session cache mode on the context.
+		SSL_CTX_set_session_cache_mode(sslcontext.impl(), session_cache_mode);
+		/*-------- DEBUG LOG --------*/
+		if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_SERVER)) {
+			LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_SERVER, 42,
+				"function : Constructor sslproxy_server::sslproxy_server() : "
+				"Set session cache mode END. "
+				"session_cache_mode = %ld",
+				SSL_CTX_get_session_cache_mode(sslcontext.impl()));
+		}
+		/*------ DEBUG LOG END ------*/
+
+		// Set session cache size on the context.
+		SSL_CTX_sess_set_cache_size(sslcontext.impl(), session_cache_size);
+		/*-------- DEBUG LOG --------*/
+		if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_SERVER)) {
+			LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_SERVER, 43,
+				"function : Constructor sslproxy_server::sslproxy_server() : "
+				"Set session cache size END. "
+				"session_cache_size = %ld",
+				SSL_CTX_sess_get_cache_size(sslcontext.impl()));
+		}
+		/*------ DEBUG LOG END ------*/
+
+		// Set session cache timeout on the context.
+		SSL_CTX_set_timeout(sslcontext.impl(), session_cache_timeout);
+		/*-------- DEBUG LOG --------*/
+		if (LOG_LV_DEBUG == logger_get_log_level(LOG_CAT_SSLPROXY_SERVER)) {
+			LOGGER_PUT_LOG_DEBUG(LOG_CAT_SSLPROXY_SERVER, 44,
+				"function : Constructor sslproxy_server::sslproxy_server() : "
+				"Set session cache timeout END. "
+				"session_cache_timeout = %ld",
+				SSL_CTX_get_timeout(sslcontext.impl()));
+		}
+		/*------ DEBUG LOG END ------*/
+
 		// Create sslproxy_session for first acception.
 		function_str = "Create sslproxy_session for first";
 		sslproxy_session* session = new sslproxy_session(sslservice,
